@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,16 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.gkehub_v1.services.gke_hub import pagers
@@ -114,6 +119,42 @@ class GkeHubAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return GkeHubClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> GkeHubTransport:
         """Returns the transport used by the client instance.
@@ -176,17 +217,37 @@ class GkeHubAsyncClient:
 
     async def list_memberships(
         self,
-        request: service.ListMembershipsRequest = None,
+        request: Union[service.ListMembershipsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMembershipsAsyncPager:
         r"""Lists Memberships in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_list_memberships():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.ListMembershipsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_memberships(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.ListMembershipsRequest`):
+            request (Union[google.cloud.gkehub_v1.types.ListMembershipsRequest, dict]):
                 The request object. Request message for
                 `GkeHub.ListMemberships` method.
             parent (:class:`str`):
@@ -212,7 +273,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -256,22 +317,41 @@ class GkeHubAsyncClient:
 
     async def list_features(
         self,
-        request: service.ListFeaturesRequest = None,
+        request: Union[service.ListFeaturesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFeaturesAsyncPager:
         r"""Lists Features in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_list_features():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.ListFeaturesRequest(
+                )
+
+                # Make the request
+                page_result = client.list_features(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.ListFeaturesRequest`):
+            request (Union[google.cloud.gkehub_v1.types.ListFeaturesRequest, dict]):
                 The request object. Request message for
                 `GkeHub.ListFeatures` method.
             parent (:class:`str`):
-                The parent (project and location) where the Features
-                will be listed. Specified in the format
+                Required. The parent (project and location) where the
+                Features will be listed. Specified in the format
                 ``projects/*/locations/*``.
 
                 This corresponds to the ``parent`` field
@@ -292,7 +372,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -336,17 +416,36 @@ class GkeHubAsyncClient:
 
     async def get_membership(
         self,
-        request: service.GetMembershipRequest = None,
+        request: Union[service.GetMembershipRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.Membership:
         r"""Gets the details of a Membership.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_get_membership():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.GetMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_membership(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.GetMembershipRequest`):
+            request (Union[google.cloud.gkehub_v1.types.GetMembershipRequest, dict]):
                 The request object. Request message for
                 `GkeHub.GetMembership` method.
             name (:class:`str`):
@@ -369,7 +468,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -407,21 +506,39 @@ class GkeHubAsyncClient:
 
     async def get_feature(
         self,
-        request: service.GetFeatureRequest = None,
+        request: Union[service.GetFeatureRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> feature.Feature:
         r"""Gets details of a single Feature.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_get_feature():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.GetFeatureRequest(
+                )
+
+                # Make the request
+                response = client.get_feature(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.GetFeatureRequest`):
+            request (Union[google.cloud.gkehub_v1.types.GetFeatureRequest, dict]):
                 The request object. Request message for
                 `GkeHub.GetFeature` method.
             name (:class:`str`):
-                The Feature resource name in the format
+                Required. The Feature resource name in the format
                 ``projects/*/locations/*/features/*``
 
                 This corresponds to the ``name`` field
@@ -440,7 +557,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -478,12 +595,12 @@ class GkeHubAsyncClient:
 
     async def create_membership(
         self,
-        request: service.CreateMembershipRequest = None,
+        request: Union[service.CreateMembershipRequest, dict] = None,
         *,
         parent: str = None,
         resource: membership.Membership = None,
         membership_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -493,8 +610,33 @@ class GkeHubAsyncClient:
         Cloud**. To register other clusters, follow the instructions at
         https://cloud.google.com/anthos/multicluster-management/connect/registering-a-cluster.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_create_membership():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.CreateMembershipRequest(
+                    parent="parent_value",
+                    membership_id="membership_id_value",
+                )
+
+                # Make the request
+                operation = client.create_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.CreateMembershipRequest`):
+            request (Union[google.cloud.gkehub_v1.types.CreateMembershipRequest, dict]):
                 The request object. Request message for the
                 `GkeHub.CreateMembership` method.
             parent (:class:`str`):
@@ -543,7 +685,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, resource, membership_id])
         if request is not None and has_flattened_params:
@@ -593,24 +735,46 @@ class GkeHubAsyncClient:
 
     async def create_feature(
         self,
-        request: service.CreateFeatureRequest = None,
+        request: Union[service.CreateFeatureRequest, dict] = None,
         *,
         parent: str = None,
         resource: feature.Feature = None,
         feature_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Adds a new Feature.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_create_feature():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.CreateFeatureRequest(
+                )
+
+                # Make the request
+                operation = client.create_feature(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.CreateFeatureRequest`):
+            request (Union[google.cloud.gkehub_v1.types.CreateFeatureRequest, dict]):
                 The request object. Request message for the
                 `GkeHub.CreateFeature` method.
             parent (:class:`str`):
-                The parent (project and location) where the Feature will
-                be created. Specified in the format
+                Required. The parent (project and location) where the
+                Feature will be created. Specified in the format
                 ``projects/*/locations/*``.
 
                 This corresponds to the ``parent`` field
@@ -642,7 +806,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, resource, feature_id])
         if request is not None and has_flattened_params:
@@ -692,10 +856,10 @@ class GkeHubAsyncClient:
 
     async def delete_membership(
         self,
-        request: service.DeleteMembershipRequest = None,
+        request: Union[service.DeleteMembershipRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -706,8 +870,32 @@ class GkeHubAsyncClient:
         at
         https://cloud.google.com/anthos/multicluster-management/connect/unregistering-a-cluster.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_delete_membership():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.DeleteMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.DeleteMembershipRequest`):
+            request (Union[google.cloud.gkehub_v1.types.DeleteMembershipRequest, dict]):
                 The request object. Request message for
                 `GkeHub.DeleteMembership` method.
             name (:class:`str`):
@@ -743,7 +931,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -789,21 +977,43 @@ class GkeHubAsyncClient:
 
     async def delete_feature(
         self,
-        request: service.DeleteFeatureRequest = None,
+        request: Union[service.DeleteFeatureRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Removes a Feature.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_delete_feature():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.DeleteFeatureRequest(
+                )
+
+                # Make the request
+                operation = client.delete_feature(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.DeleteFeatureRequest`):
+            request (Union[google.cloud.gkehub_v1.types.DeleteFeatureRequest, dict]):
                 The request object. Request message for
                 `GkeHub.DeleteFeature` method.
             name (:class:`str`):
-                The Feature resource name in the format
+                Required. The Feature resource name in the format
                 ``projects/*/locations/*/features/*``.
 
                 This corresponds to the ``name`` field
@@ -835,7 +1045,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -881,19 +1091,42 @@ class GkeHubAsyncClient:
 
     async def update_membership(
         self,
-        request: service.UpdateMembershipRequest = None,
+        request: Union[service.UpdateMembershipRequest, dict] = None,
         *,
         name: str = None,
         resource: membership.Membership = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates an existing Membership.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_update_membership():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.UpdateMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.update_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.UpdateMembershipRequest`):
+            request (Union[google.cloud.gkehub_v1.types.UpdateMembershipRequest, dict]):
                 The request object. Request message for
                 `GkeHub.UpdateMembership` method.
             name (:class:`str`):
@@ -938,7 +1171,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, resource, update_mask])
         if request is not None and has_flattened_params:
@@ -988,23 +1221,45 @@ class GkeHubAsyncClient:
 
     async def update_feature(
         self,
-        request: service.UpdateFeatureRequest = None,
+        request: Union[service.UpdateFeatureRequest, dict] = None,
         *,
         name: str = None,
         resource: feature.Feature = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates an existing Feature.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_update_feature():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.UpdateFeatureRequest(
+                )
+
+                # Make the request
+                operation = client.update_feature(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.UpdateFeatureRequest`):
+            request (Union[google.cloud.gkehub_v1.types.UpdateFeatureRequest, dict]):
                 The request object. Request message for
                 `GkeHub.UpdateFeature` method.
             name (:class:`str`):
-                The Feature resource name in the format
+                Required. The Feature resource name in the format
                 ``projects/*/locations/*/features/*``.
 
                 This corresponds to the ``name`` field
@@ -1045,7 +1300,7 @@ class GkeHubAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, resource, update_mask])
         if request is not None and has_flattened_params:
@@ -1095,9 +1350,9 @@ class GkeHubAsyncClient:
 
     async def generate_connect_manifest(
         self,
-        request: service.GenerateConnectManifestRequest = None,
+        request: Union[service.GenerateConnectManifestRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.GenerateConnectManifestResponse:
@@ -1106,8 +1361,28 @@ class GkeHubAsyncClient:
         **This method is used internally by Google-provided libraries.**
         Most clients should not need to call this method directly.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_generate_connect_manifest():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.GenerateConnectManifestRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.generate_connect_manifest(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1.types.GenerateConnectManifestRequest`):
+            request (Union[google.cloud.gkehub_v1.types.GenerateConnectManifestRequest, dict]):
                 The request object. Request message for
                 `GkeHub.GenerateConnectManifest` method.
                 .
