@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,22 +14,26 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.gkehub_v1.services.gke_hub import pagers
@@ -265,6 +269,73 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -315,50 +386,22 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, GkeHubTransport):
             # transport is a GkeHubTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -370,6 +413,15 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -387,12 +439,32 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         request: Union[service.ListMembershipsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMembershipsPager:
         r"""Lists Memberships in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_list_memberships():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.ListMembershipsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_memberships(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.ListMembershipsRequest, dict]):
                 The request object. Request message for
@@ -420,7 +492,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -467,19 +539,38 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         request: Union[service.ListFeaturesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFeaturesPager:
         r"""Lists Features in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_list_features():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.ListFeaturesRequest(
+                )
+
+                # Make the request
+                page_result = client.list_features(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.ListFeaturesRequest, dict]):
                 The request object. Request message for
                 `GkeHub.ListFeatures` method.
             parent (str):
-                The parent (project and location) where the Features
-                will be listed. Specified in the format
+                Required. The parent (project and location) where the
+                Features will be listed. Specified in the format
                 ``projects/*/locations/*``.
 
                 This corresponds to the ``parent`` field
@@ -500,7 +591,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -547,12 +638,31 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         request: Union[service.GetMembershipRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.Membership:
         r"""Gets the details of a Membership.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_get_membership():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.GetMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_membership(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.GetMembershipRequest, dict]):
                 The request object. Request message for
@@ -577,7 +687,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -618,18 +728,36 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         request: Union[service.GetFeatureRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> feature.Feature:
         r"""Gets details of a single Feature.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_get_feature():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.GetFeatureRequest(
+                )
+
+                # Make the request
+                response = client.get_feature(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.GetFeatureRequest, dict]):
                 The request object. Request message for
                 `GkeHub.GetFeature` method.
             name (str):
-                The Feature resource name in the format
+                Required. The Feature resource name in the format
                 ``projects/*/locations/*/features/*``
 
                 This corresponds to the ``name`` field
@@ -648,7 +776,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -691,7 +819,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         parent: str = None,
         resource: membership.Membership = None,
         membership_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -701,6 +829,31 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         Cloud**. To register other clusters, follow the instructions at
         https://cloud.google.com/anthos/multicluster-management/connect/registering-a-cluster.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_create_membership():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.CreateMembershipRequest(
+                    parent="parent_value",
+                    membership_id="membership_id_value",
+                )
+
+                # Make the request
+                operation = client.create_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.CreateMembershipRequest, dict]):
                 The request object. Request message for the
@@ -751,7 +904,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, resource, membership_id])
         if request is not None and has_flattened_params:
@@ -806,19 +959,41 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         parent: str = None,
         resource: feature.Feature = None,
         feature_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Adds a new Feature.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_create_feature():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.CreateFeatureRequest(
+                )
+
+                # Make the request
+                operation = client.create_feature(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.CreateFeatureRequest, dict]):
                 The request object. Request message for the
                 `GkeHub.CreateFeature` method.
             parent (str):
-                The parent (project and location) where the Feature will
-                be created. Specified in the format
+                Required. The parent (project and location) where the
+                Feature will be created. Specified in the format
                 ``projects/*/locations/*``.
 
                 This corresponds to the ``parent`` field
@@ -850,7 +1025,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, resource, feature_id])
         if request is not None and has_flattened_params:
@@ -903,7 +1078,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         request: Union[service.DeleteMembershipRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -914,6 +1089,30 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         at
         https://cloud.google.com/anthos/multicluster-management/connect/unregistering-a-cluster.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_delete_membership():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.DeleteMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.DeleteMembershipRequest, dict]):
                 The request object. Request message for
@@ -951,7 +1150,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1000,18 +1199,40 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         request: Union[service.DeleteFeatureRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Removes a Feature.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_delete_feature():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.DeleteFeatureRequest(
+                )
+
+                # Make the request
+                operation = client.delete_feature(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.DeleteFeatureRequest, dict]):
                 The request object. Request message for
                 `GkeHub.DeleteFeature` method.
             name (str):
-                The Feature resource name in the format
+                Required. The Feature resource name in the format
                 ``projects/*/locations/*/features/*``.
 
                 This corresponds to the ``name`` field
@@ -1043,7 +1264,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1094,12 +1315,35 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         name: str = None,
         resource: membership.Membership = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates an existing Membership.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_update_membership():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.UpdateMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.update_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.UpdateMembershipRequest, dict]):
                 The request object. Request message for
@@ -1146,7 +1390,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, resource, update_mask])
         if request is not None and has_flattened_params:
@@ -1201,18 +1445,40 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         name: str = None,
         resource: feature.Feature = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates an existing Feature.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_update_feature():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.UpdateFeatureRequest(
+                )
+
+                # Make the request
+                operation = client.update_feature(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.UpdateFeatureRequest, dict]):
                 The request object. Request message for
                 `GkeHub.UpdateFeature` method.
             name (str):
-                The Feature resource name in the format
+                Required. The Feature resource name in the format
                 ``projects/*/locations/*/features/*``.
 
                 This corresponds to the ``name`` field
@@ -1253,7 +1519,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, resource, update_mask])
         if request is not None and has_flattened_params:
@@ -1305,7 +1571,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         self,
         request: Union[service.GenerateConnectManifestRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.GenerateConnectManifestResponse:
@@ -1314,6 +1580,26 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         **This method is used internally by Google-provided libraries.**
         Most clients should not need to call this method directly.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1
+
+            def sample_generate_connect_manifest():
+                # Create a client
+                client = gkehub_v1.GkeHubClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1.GenerateConnectManifestRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.generate_connect_manifest(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gkehub_v1.types.GenerateConnectManifestRequest, dict]):
                 The request object. Request message for
