@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -77,8 +77,8 @@ class Feature(proto.Message):
             Output only. The Hub-wide Feature state.
         membership_states (Sequence[google.cloud.gkehub_v1.types.Feature.MembershipStatesEntry]):
             Output only. Membership-specific Feature
-            status. If this Feature does report any per-
-            Membership status, this field may be unused.
+            status. If this Feature does report any
+            per-Membership status, this field may be unused.
             The keys indicate which Membership the state is
             for, in the form:
             `projects/{p}/locations/{l}/memberships/{m}`
@@ -153,8 +153,8 @@ class FeatureState(proto.Message):
             A human-readable description of the current
             status.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
-            The time this status and any related Feature-
-            pecific details were updated.
+            The time this status and any related
+            Feature-specific details were updated.
     """
 
     class Code(proto.Enum):
@@ -174,9 +174,13 @@ class FeatureState(proto.Message):
 class CommonFeatureSpec(proto.Message):
     r"""CommonFeatureSpec contains Hub-wide configuration information
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         multiclusteringress (google.cloud.gkehub_v1.multiclusteringress_v1.FeatureSpec):
             Multicluster Ingress-specific spec.
+
+            This field is a member of `oneof`_ ``feature_spec``.
     """
 
     multiclusteringress = proto.Field(
@@ -204,9 +208,14 @@ class MembershipFeatureSpec(proto.Message):
     r"""MembershipFeatureSpec contains configuration information for
     a single Membership.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         configmanagement (google.cloud.gkehub_v1.configmanagement_v1.MembershipSpec):
             Config Management-specific spec.
+
+            This field is a member of `oneof`_ ``feature_spec``.
     """
 
     configmanagement = proto.Field(
@@ -221,9 +230,14 @@ class MembershipFeatureState(proto.Message):
     r"""MembershipFeatureState contains Feature status information
     for a single Membership.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         configmanagement (google.cloud.gkehub_v1.configmanagement_v1.MembershipState):
             Config Management-specific state.
+
+            This field is a member of `oneof`_ ``feature_state``.
         state (google.cloud.gkehub_v1.types.FeatureState):
             The high-level state of this Feature for a
             single membership.
