@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,16 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.gkehub_v1beta1.services.gke_hub_membership_service import pagers
@@ -40,9 +45,15 @@ from .client import GkeHubMembershipServiceClient
 
 
 class GkeHubMembershipServiceAsyncClient:
-    """GKE Hub CRUD API for the Membership resource.
-    The Membership service is currently only available in the global
-    location.
+    """The GKE Hub MembershipService handles the registration of many
+    Kubernetes clusters to Google Cloud, represented with the
+    [Membership][google.cloud.gkehub.v1beta1.Membership] resource.
+
+    GKE Hub is currently only available in the global region.
+
+    **Membership management may be non-trivial:** it is recommended to
+    use one of the Google-provided client libraries or tools where
+    possible when working with Membership resources.
     """
 
     _client: GkeHubMembershipServiceClient
@@ -116,6 +127,42 @@ class GkeHubMembershipServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return GkeHubMembershipServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> GkeHubMembershipServiceTransport:
         """Returns the transport used by the client instance.
@@ -179,17 +226,37 @@ class GkeHubMembershipServiceAsyncClient:
 
     async def list_memberships(
         self,
-        request: membership.ListMembershipsRequest = None,
+        request: Union[membership.ListMembershipsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMembershipsAsyncPager:
         r"""Lists Memberships in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_list_memberships():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.ListMembershipsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_memberships(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1beta1.types.ListMembershipsRequest`):
+            request (Union[google.cloud.gkehub_v1beta1.types.ListMembershipsRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.ListMemberships` method.
             parent (:class:`str`):
@@ -216,7 +283,7 @@ class GkeHubMembershipServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -260,17 +327,36 @@ class GkeHubMembershipServiceAsyncClient:
 
     async def get_membership(
         self,
-        request: membership.GetMembershipRequest = None,
+        request: Union[membership.GetMembershipRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.Membership:
         r"""Gets the details of a Membership.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_get_membership():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.GetMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_membership(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1beta1.types.GetMembershipRequest`):
+            request (Union[google.cloud.gkehub_v1beta1.types.GetMembershipRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.GetMembership` method.
             name (:class:`str`):
@@ -293,7 +379,7 @@ class GkeHubMembershipServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -331,19 +417,48 @@ class GkeHubMembershipServiceAsyncClient:
 
     async def create_membership(
         self,
-        request: membership.CreateMembershipRequest = None,
+        request: Union[membership.CreateMembershipRequest, dict] = None,
         *,
         parent: str = None,
         resource: membership.Membership = None,
         membership_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
-        r"""Adds a new Membership.
+        r"""Creates a new Membership.
+
+        **This is currently only supported for GKE clusters on Google
+        Cloud**. To register other clusters, follow the instructions at
+        https://cloud.google.com/anthos/multicluster-management/connect/registering-a-cluster.
+
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_create_membership():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.CreateMembershipRequest(
+                    parent="parent_value",
+                    membership_id="membership_id_value",
+                )
+
+                # Make the request
+                operation = client.create_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
 
         Args:
-            request (:class:`google.cloud.gkehub_v1beta1.types.CreateMembershipRequest`):
+            request (Union[google.cloud.gkehub_v1beta1.types.CreateMembershipRequest, dict]):
                 The request object. Request message for the
                 `GkeHubMembershipService.CreateMembership` method.
             parent (:class:`str`):
@@ -392,7 +507,7 @@ class GkeHubMembershipServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, resource, membership_id])
         if request is not None and has_flattened_params:
@@ -442,17 +557,46 @@ class GkeHubMembershipServiceAsyncClient:
 
     async def delete_membership(
         self,
-        request: membership.DeleteMembershipRequest = None,
+        request: Union[membership.DeleteMembershipRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Removes a Membership.
 
+        **This is currently only supported for GKE clusters on Google
+        Cloud**. To unregister other clusters, follow the instructions
+        at
+        https://cloud.google.com/anthos/multicluster-management/connect/unregistering-a-cluster.
+
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_delete_membership():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.DeleteMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1beta1.types.DeleteMembershipRequest`):
+            request (Union[google.cloud.gkehub_v1beta1.types.DeleteMembershipRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.DeleteMembership` method.
             name (:class:`str`):
@@ -488,7 +632,7 @@ class GkeHubMembershipServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -534,19 +678,42 @@ class GkeHubMembershipServiceAsyncClient:
 
     async def update_membership(
         self,
-        request: membership.UpdateMembershipRequest = None,
+        request: Union[membership.UpdateMembershipRequest, dict] = None,
         *,
         name: str = None,
         resource: membership.Membership = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates an existing Membership.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_update_membership():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.UpdateMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.update_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1beta1.types.UpdateMembershipRequest`):
+            request (Union[google.cloud.gkehub_v1beta1.types.UpdateMembershipRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.UpdateMembership` method.
             name (:class:`str`):
@@ -563,7 +730,9 @@ class GkeHubMembershipServiceAsyncClient:
                 If you are updating a map field, set the value of a key
                 to null or empty string to delete the key from the map.
                 It's not possible to update a key's value to the empty
-                string.
+                string. If you specify the update_mask to be a special
+                path "*", fully replaces all user-modifiable fields to
+                match ``resource``.
 
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -592,7 +761,7 @@ class GkeHubMembershipServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, resource, update_mask])
         if request is not None and has_flattened_params:
@@ -642,17 +811,39 @@ class GkeHubMembershipServiceAsyncClient:
 
     async def generate_connect_manifest(
         self,
-        request: membership.GenerateConnectManifestRequest = None,
+        request: Union[membership.GenerateConnectManifestRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.GenerateConnectManifestResponse:
-        r"""Generates the manifest for deployment of the GKE
-        connect agent.
+        r"""Generates the manifest for deployment of the GKE connect agent.
+
+        **This method is used internally by Google-provided libraries.**
+        Most clients should not need to call this method directly.
+
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_generate_connect_manifest():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.GenerateConnectManifestRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.generate_connect_manifest(request=request)
+
+                # Handle the response
+                print(response)
 
         Args:
-            request (:class:`google.cloud.gkehub_v1beta1.types.GenerateConnectManifestRequest`):
+            request (Union[google.cloud.gkehub_v1beta1.types.GenerateConnectManifestRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.GenerateConnectManifest`
                 method. .
@@ -694,9 +885,9 @@ class GkeHubMembershipServiceAsyncClient:
 
     async def validate_exclusivity(
         self,
-        request: membership.ValidateExclusivityRequest = None,
+        request: Union[membership.ValidateExclusivityRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.ValidateExclusivityResponse:
@@ -704,8 +895,29 @@ class GkeHubMembershipServiceAsyncClient:
         exclusivity in the cluster. The validation does not
         depend on an existing Hub membership resource.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_validate_exclusivity():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.ValidateExclusivityRequest(
+                    parent="parent_value",
+                    intended_membership="intended_membership_value",
+                )
+
+                # Make the request
+                response = client.validate_exclusivity(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1beta1.types.ValidateExclusivityRequest`):
+            request (Union[google.cloud.gkehub_v1beta1.types.ValidateExclusivityRequest, dict]):
                 The request object. The request to validate the existing
                 state of the membership CR in the cluster.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -745,9 +957,9 @@ class GkeHubMembershipServiceAsyncClient:
 
     async def generate_exclusivity_manifest(
         self,
-        request: membership.GenerateExclusivityManifestRequest = None,
+        request: Union[membership.GenerateExclusivityManifestRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.GenerateExclusivityManifestResponse:
@@ -766,8 +978,28 @@ class GkeHubMembershipServiceAsyncClient:
         response will be the converted CRD and CR if there are
         any differences between the versions.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_generate_exclusivity_manifest():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.GenerateExclusivityManifestRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.generate_exclusivity_manifest(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.gkehub_v1beta1.types.GenerateExclusivityManifestRequest`):
+            request (Union[google.cloud.gkehub_v1beta1.types.GenerateExclusivityManifestRequest, dict]):
                 The request object. The request to generate the
                 manifests for exclusivity artifacts.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -806,6 +1038,12 @@ class GkeHubMembershipServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
