@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,22 +14,26 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.gkehub_v1beta1.services.gke_hub_membership_service import pagers
@@ -79,9 +83,15 @@ class GkeHubMembershipServiceClientMeta(type):
 
 
 class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta):
-    """GKE Hub CRUD API for the Membership resource.
-    The Membership service is currently only available in the global
-    location.
+    """The GKE Hub MembershipService handles the registration of many
+    Kubernetes clusters to Google Cloud, represented with the
+    [Membership][google.cloud.gkehub.v1beta1.Membership] resource.
+
+    GKE Hub is currently only available in the global region.
+
+    **Membership management may be non-trivial:** it is recommended to
+    use one of the Google-provided client libraries or tools where
+    possible when working with Membership resources.
     """
 
     @staticmethod
@@ -241,6 +251,73 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -291,50 +368,22 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, GkeHubMembershipServiceTransport):
             # transport is a GkeHubMembershipServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -346,6 +395,15 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -355,21 +413,42 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def list_memberships(
         self,
-        request: membership.ListMembershipsRequest = None,
+        request: Union[membership.ListMembershipsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMembershipsPager:
         r"""Lists Memberships in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_list_memberships():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.ListMembershipsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_memberships(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (google.cloud.gkehub_v1beta1.types.ListMembershipsRequest):
+            request (Union[google.cloud.gkehub_v1beta1.types.ListMembershipsRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.ListMemberships` method.
             parent (str):
@@ -396,7 +475,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -440,17 +519,36 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def get_membership(
         self,
-        request: membership.GetMembershipRequest = None,
+        request: Union[membership.GetMembershipRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.Membership:
         r"""Gets the details of a Membership.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_get_membership():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.GetMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_membership(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.gkehub_v1beta1.types.GetMembershipRequest):
+            request (Union[google.cloud.gkehub_v1beta1.types.GetMembershipRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.GetMembership` method.
             name (str):
@@ -473,7 +571,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -511,19 +609,48 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def create_membership(
         self,
-        request: membership.CreateMembershipRequest = None,
+        request: Union[membership.CreateMembershipRequest, dict] = None,
         *,
         parent: str = None,
         resource: membership.Membership = None,
         membership_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
-        r"""Adds a new Membership.
+        r"""Creates a new Membership.
+
+        **This is currently only supported for GKE clusters on Google
+        Cloud**. To register other clusters, follow the instructions at
+        https://cloud.google.com/anthos/multicluster-management/connect/registering-a-cluster.
+
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_create_membership():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.CreateMembershipRequest(
+                    parent="parent_value",
+                    membership_id="membership_id_value",
+                )
+
+                # Make the request
+                operation = client.create_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
 
         Args:
-            request (google.cloud.gkehub_v1beta1.types.CreateMembershipRequest):
+            request (Union[google.cloud.gkehub_v1beta1.types.CreateMembershipRequest, dict]):
                 The request object. Request message for the
                 `GkeHubMembershipService.CreateMembership` method.
             parent (str):
@@ -572,7 +699,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, resource, membership_id])
         if request is not None and has_flattened_params:
@@ -622,17 +749,46 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def delete_membership(
         self,
-        request: membership.DeleteMembershipRequest = None,
+        request: Union[membership.DeleteMembershipRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Removes a Membership.
 
+        **This is currently only supported for GKE clusters on Google
+        Cloud**. To unregister other clusters, follow the instructions
+        at
+        https://cloud.google.com/anthos/multicluster-management/connect/unregistering-a-cluster.
+
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_delete_membership():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.DeleteMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.gkehub_v1beta1.types.DeleteMembershipRequest):
+            request (Union[google.cloud.gkehub_v1beta1.types.DeleteMembershipRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.DeleteMembership` method.
             name (str):
@@ -668,7 +824,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -714,19 +870,42 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def update_membership(
         self,
-        request: membership.UpdateMembershipRequest = None,
+        request: Union[membership.UpdateMembershipRequest, dict] = None,
         *,
         name: str = None,
         resource: membership.Membership = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates an existing Membership.
 
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_update_membership():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.UpdateMembershipRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.update_membership(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.gkehub_v1beta1.types.UpdateMembershipRequest):
+            request (Union[google.cloud.gkehub_v1beta1.types.UpdateMembershipRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.UpdateMembership` method.
             name (str):
@@ -743,7 +922,9 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
                 If you are updating a map field, set the value of a key
                 to null or empty string to delete the key from the map.
                 It's not possible to update a key's value to the empty
-                string.
+                string. If you specify the update_mask to be a special
+                path "*", fully replaces all user-modifiable fields to
+                match ``resource``.
 
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -772,7 +953,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, resource, update_mask])
         if request is not None and has_flattened_params:
@@ -822,17 +1003,39 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def generate_connect_manifest(
         self,
-        request: membership.GenerateConnectManifestRequest = None,
+        request: Union[membership.GenerateConnectManifestRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.GenerateConnectManifestResponse:
-        r"""Generates the manifest for deployment of the GKE
-        connect agent.
+        r"""Generates the manifest for deployment of the GKE connect agent.
+
+        **This method is used internally by Google-provided libraries.**
+        Most clients should not need to call this method directly.
+
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_generate_connect_manifest():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.GenerateConnectManifestRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.generate_connect_manifest(request=request)
+
+                # Handle the response
+                print(response)
 
         Args:
-            request (google.cloud.gkehub_v1beta1.types.GenerateConnectManifestRequest):
+            request (Union[google.cloud.gkehub_v1beta1.types.GenerateConnectManifestRequest, dict]):
                 The request object. Request message for
                 `GkeHubMembershipService.GenerateConnectManifest`
                 method. .
@@ -877,9 +1080,9 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def validate_exclusivity(
         self,
-        request: membership.ValidateExclusivityRequest = None,
+        request: Union[membership.ValidateExclusivityRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.ValidateExclusivityResponse:
@@ -887,8 +1090,29 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         exclusivity in the cluster. The validation does not
         depend on an existing Hub membership resource.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_validate_exclusivity():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.ValidateExclusivityRequest(
+                    parent="parent_value",
+                    intended_membership="intended_membership_value",
+                )
+
+                # Make the request
+                response = client.validate_exclusivity(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.gkehub_v1beta1.types.ValidateExclusivityRequest):
+            request (Union[google.cloud.gkehub_v1beta1.types.ValidateExclusivityRequest, dict]):
                 The request object. The request to validate the existing
                 state of the membership CR in the cluster.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -929,9 +1153,9 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def generate_exclusivity_manifest(
         self,
-        request: membership.GenerateExclusivityManifestRequest = None,
+        request: Union[membership.GenerateExclusivityManifestRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.GenerateExclusivityManifestResponse:
@@ -950,8 +1174,28 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         response will be the converted CRD and CR if there are
         any differences between the versions.
 
+
+        .. code-block:: python
+
+            from google.cloud import gkehub_v1beta1
+
+            def sample_generate_exclusivity_manifest():
+                # Create a client
+                client = gkehub_v1beta1.GkeHubMembershipServiceClient()
+
+                # Initialize request argument(s)
+                request = gkehub_v1beta1.GenerateExclusivityManifestRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.generate_exclusivity_manifest(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.gkehub_v1beta1.types.GenerateExclusivityManifestRequest):
+            request (Union[google.cloud.gkehub_v1beta1.types.GenerateExclusivityManifestRequest, dict]):
                 The request object. The request to generate the
                 manifests for exclusivity artifacts.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -993,6 +1237,19 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
