@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,9 +16,9 @@
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
-from google.api_core import grpc_helpers  # type: ignore
-from google.api_core import operations_v1  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
+from google.api_core import grpc_helpers
+from google.api_core import operations_v1
+from google.api_core import gapic_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
@@ -33,9 +33,15 @@ from .base import GkeHubMembershipServiceTransport, DEFAULT_CLIENT_INFO
 class GkeHubMembershipServiceGrpcTransport(GkeHubMembershipServiceTransport):
     """gRPC backend transport for GkeHubMembershipService.
 
-    GKE Hub CRUD API for the Membership resource.
-    The Membership service is currently only available in the global
-    location.
+    The GKE Hub MembershipService handles the registration of many
+    Kubernetes clusters to Google Cloud, represented with the
+    [Membership][google.cloud.gkehub.v1beta1.Membership] resource.
+
+    GKE Hub is currently only available in the global region.
+
+    **Membership management may be non-trivial:** it is recommended to
+    use one of the Google-provided client libraries or tools where
+    possible when working with Membership resources.
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -84,16 +90,16 @@ class GkeHubMembershipServiceGrpcTransport(GkeHubMembershipServiceTransport):
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
-                ``client_cert_source`` or applicatin default SSL credentials.
+                ``client_cert_source`` or application default SSL credentials.
             client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 Deprecated. A callback to provide client SSL certificate bytes and
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 A callback to provide client certificate bytes and private key bytes,
-                both in PEM format. It is used to configure mutual TLS channel. It is
+                both in PEM format. It is used to configure a mutual TLS channel. It is
                 ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
@@ -114,7 +120,7 @@ class GkeHubMembershipServiceGrpcTransport(GkeHubMembershipServiceTransport):
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -163,8 +169,11 @@ class GkeHubMembershipServiceGrpcTransport(GkeHubMembershipServiceTransport):
         if not self._grpc_channel:
             self._grpc_channel = type(self).create_channel(
                 self._host,
+                # use the credentials which are saved
                 credentials=self._credentials,
-                credentials_file=credentials_file,
+                # Set ``credentials_file`` to ``None`` here as
+                # the credentials that we saved earlier should be used.
+                credentials_file=None,
                 scopes=self._scopes,
                 ssl_credentials=self._ssl_channel_credentials,
                 quota_project_id=quota_project_id,
@@ -237,7 +246,7 @@ class GkeHubMembershipServiceGrpcTransport(GkeHubMembershipServiceTransport):
         This property caches on the instance; repeated calls return the same
         client.
         """
-        # Sanity check: Only create a new client if we do not already have one.
+        # Quick check: Only create a new client if we do not already have one.
         if self._operations_client is None:
             self._operations_client = operations_v1.OperationsClient(self.grpc_channel)
 
@@ -304,7 +313,11 @@ class GkeHubMembershipServiceGrpcTransport(GkeHubMembershipServiceTransport):
     ) -> Callable[[membership.CreateMembershipRequest], operations_pb2.Operation]:
         r"""Return a callable for the create membership method over gRPC.
 
-        Adds a new Membership.
+        Creates a new Membership.
+
+        **This is currently only supported for GKE clusters on Google
+        Cloud**. To register other clusters, follow the instructions at
+        https://cloud.google.com/anthos/multicluster-management/connect/registering-a-cluster.
 
         Returns:
             Callable[[~.CreateMembershipRequest],
@@ -332,6 +345,11 @@ class GkeHubMembershipServiceGrpcTransport(GkeHubMembershipServiceTransport):
 
         Removes a Membership.
 
+        **This is currently only supported for GKE clusters on Google
+        Cloud**. To unregister other clusters, follow the instructions
+        at
+        https://cloud.google.com/anthos/multicluster-management/connect/unregistering-a-cluster.
+
         Returns:
             Callable[[~.DeleteMembershipRequest],
                     ~.Operation]:
@@ -385,8 +403,10 @@ class GkeHubMembershipServiceGrpcTransport(GkeHubMembershipServiceTransport):
     ]:
         r"""Return a callable for the generate connect manifest method over gRPC.
 
-        Generates the manifest for deployment of the GKE
-        connect agent.
+        Generates the manifest for deployment of the GKE connect agent.
+
+        **This method is used internally by Google-provided libraries.**
+        Most clients should not need to call this method directly.
 
         Returns:
             Callable[[~.GenerateConnectManifestRequest],
@@ -480,5 +500,8 @@ class GkeHubMembershipServiceGrpcTransport(GkeHubMembershipServiceTransport):
             )
         return self._stubs["generate_exclusivity_manifest"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("GkeHubMembershipServiceGrpcTransport",)
